<?php
// $Id$

/**
 * @file page.tpl.php
 *
 * Theme implementation to display a single Drupal page.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $css: An array of CSS files for the current page.
 * - $directory: The directory the theme is located in, e.g. themes/garland or
 *   themes/garland/minelli.
 * - $is_front: TRUE if the current page is the front page. Used to toggle the mission statement.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Page metadata:
 * - $language: (object) The language the site is being displayed in.
 *   $language->language contains its textual representation.
 *   $language->dir contains the language direction. It will either be 'ltr' or 'rtl'.
 * - $head_title: A modified version of the page title, for use in the TITLE tag.
 * - $head: Markup for the HEAD section (including meta tags, keyword tags, and
 *   so on).
 * - $styles: Style tags necessary to import all CSS files for the page.
 * - $scripts: Script tags necessary to load the JavaScript files and settings
 *   for the page.
 * - $body_classes: A set of CSS classes for the BODY tag. This contains flags
 *   indicating the current layout (multiple columns, single column), the current
 *   path, whether the user is logged in, and so on.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * - $mission: The text of the site mission, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $search_box: HTML to display the search box, empty if search has been disabled.
 * - $primary_links (array): An array containing primary navigation links for the
 *   site, if they have been configured.
 * - $secondary_links (array): An array containing secondary navigation links for
 *   the site, if they have been configured.
 *
 * Page content (in order of occurrance in the default page.tpl.php):
 * - $left: The HTML for the left sidebar.
 *
 * - $breadcrumb: The breadcrumb trail for the current page.
 * - $title: The page title, for use in the actual HTML content.
 * - $help: Dynamic help text, mostly for admin pages.
 * - $messages: HTML for status and error messages. Should be displayed prominently.
 * - $tabs: Tabs linking to any sub-pages beneath the current page (e.g., the view
 *   and edit tabs when displaying a node).
 *
 * - $content: The main content of the current Drupal page.
 *
 * - $right: The HTML for the right sidebar.
 *
 * Footer/closing data:
 * - $feed_icons: A string of all feed icons for the current page.
 * - $footer_message: The footer message as defined in the admin settings.
 * - $footer : The footer region.
 * - $closure: Final closing markup from any modules that have altered the page.
 *   This variable should always be output last, after all other dynamic content.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 */

?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">

<head>
  <title><?php print $head_title; ?></title>
  <?php print $head; ?>
  <?php print $styles; ?>
<!--[if lte IE 6]>
  <link rel="stylesheet" type="text/css" href="<?php print base_path() . path_to_theme() .'/' ?>style_ie6.css" />
  <script type="text/javascript">
    var template_url = '<?php print base_path() . path_to_theme() .'/' ?>';
  </script>
  <style type="text/css" media="screen">
  /* IE6 PNG Fix */
  #shadow, #content ul li, ul li ul li, #shadowbottom {
    behavior: url('<?php print base_path() . path_to_theme() .'/' ?>iepngfix.htc');
  }
  </style>
<![endif]-->
  <?php print $scripts; ?>
  <script type="text/javascript"><?php /* Needed to avoid Flash of Unstyled Content in IE */ ?> </script>
</head>

<body class="<?php print $language->language; ?>">
<div id="wrapper">
  <div id="shadow">
    <div id="page">
      <div id="sidebar">
        
          <?php
            if ($logo || $site_name) {
              print '<div id="header"><h1 class="headertitle"><a href="'. check_url($front_page) .'" title="'. $site_name .'">';
              if ($logo) {
                print '<img src="'. check_url($logo) .'" alt="'. $site_name .'" id="logo" />';
              }
              else {
	            print $site_name;
              }
              print $site_html .'</a></h1></div>';
            }
          ?>
        
        <?php print $left; ?>
      <!-- Please respect my work and keep the Miss Design logo on the bottom of the sidebar. -->
      <div class="mdlogo"><a href="http://www.missdesign.co.uk"><img src="<?php print base_path() . path_to_theme() .'/' ?>images/mdlogo.png" alt="Pink Ribbon theme by Rosana Kooymans at Miss Design" title="Pink Ribbon theme by Rosana Kooymans at Miss Design" /></a></div>
      </div>
      <div id="content">
        <h1 class="title"><a href="<?php print base_path(); ?>"><?php print $site_name; ?></a></h1>
        <h5 class="description"><?php print $site_slogan; ?></h5>
        <h5 class="mission"><?php print $mission; ?></h5>
        <div class="hr"/></div>
        <?php if (!empty($title)): ?><h3 class="storytitle"><?php print $title; ?></h3><?php endif; ?>
        <?php if (!empty($tabs)): ?><div class="tabs"><?php print $tabs; ?></div><?php endif; ?>
              <?php if (!empty($messages)): print $messages; endif; ?>
              <?php if (!empty($help)): print $help; endif; ?>
              <?php print $content; ?>
      </div>
    <div class="clear"></div>
    </div>
  </div>
  <div id="shadowbottom"></div>
  <div id="footer"><?php print $footer_message; ?>
  <!-- Please respect my work and keep the Miss Design text link visible in the footer. -->
  <?php if (!empty($footer)): print $footer; endif; ?><br/>Powered by <a href="http://www.drupal.org">Drupal</a>. Pink Ribbon Theme by <a href="http://www.missdesign.co.uk">Miss Design</a>.</div>

<?php print $closure; ?>
</body>
</html>